@@ -57,7 +57,7 @@ class StickProtocol():
 
 
 
-    def get_pre_key_bundle(self, data, user_id):
+    def get_pre_key_bundle(self, data):
         """
         The following get method is used to fetch the PreKeyBundle of user to create a pairwise signal session. The request must contain
         a boolean `isSticky` to know whether this bundle would be used to communicate a SenderKey or not. If it will be used to
@@ -68,7 +68,7 @@ class StickProtocol():
         userId = data['userId']
         deviceId = data['deviceId']
         isSticky = data['isSticky']
-        user = self.User.objects.get(id=user_id)
+        user = self.User.objects.get(id=userId)
         identityKey = IdentityKey.objects.get(user=user)
         signedPreKey = SignedPreKey.objects.get(user=user)
         preKey = PreKey.objects.filter(user=user, used=False).first()
@@ -363,13 +363,13 @@ class StickProtocol():
 
 
 
-    def get_stick_id(self, data):
+    def get_stick_id(self, data, currentUser):
         """
         This method gets the active sticky session stickId associated with a particular partyId that already exists, and
         its current step.
         """
         partyId = data['partyId']
-        senderKeys = EncryptingSenderKey.objects.filter(partyId=partyId, user=user).reverse()
+        senderKeys = EncryptingSenderKey.objects.filter(partyId=partyId, user=currentUser).reverse()
         activeSenderKey = senderKeys[0]
         responseDict = {}
         if activeSenderKey.step < 100:
@@ -481,19 +481,6 @@ class StickProtocol():
             bundle['senderKeys'] = senderKeys
             user.oneTimeId = uuid.uuid4()
             user.save()
-            # LimitedAccessToken.objects.get(phone=data['phone']).delete()
-            return {"bundle": bundle, "success": True}
+            return {"bundle": bundle, "verify": True}
         else:
-            return {"success": False}
-
-
-
-    # def get_one_time_id(self, data):
-    #     """
-    #     This method is used to fetch the OneTimeId of a user.
-    #     An example of usage is when entering a chat room a user need to know
-    #     the current oneTimeId of the recipient.
-    #     """
-    #     id = request.GET.get("id")
-    #     user = User.objects.get(id=id)
-    #     return Response({"oneTimeId": user.oneTimeId})
+            return {"verify": False}
